@@ -556,7 +556,7 @@ spplot.key = function(sp.layout, rows = 1, cols = 1) {
 
 longlat.scales = function(obj, scales, xlim, ylim) {
 	isp = is.projected(obj)
-	if (!is.null(scales$draw) && !is.na(isp) && !isp) {
+	if (!is.null(scales$draw) && scales$draw && !is.na(isp) && !isp) {
 		# long lat -- x:
 		if (is.null(scales$x))
 			scales$x = list()
